// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018

// Code below takes two CSV (raw data from Qualtrics), cleans it, and turns it into data for analyis
// The below code does not have to be run on replication data because it includes identifying information (name, street address, email address), but it is included below to show how we processed the raw data from Qualtrics

// This code takes the two contributor datasets from Qualtrics (as CSVs) and appends them together in a DTA file.
// We used a different Qualtrics link for those sampled via email and those sampled via postcard
// Postcard recieptants had to put in a unique pin so that we could match them with their contribution records; whereas, those sampled via email could be matched on email address
// After appending, this code:
// (A) creates treatment variables
// (B) Drops incompletes, drops those who did not get past the JavaScript check (a requirement to see the candidate vignette), and drops those on a cell phone (also didnt get past JS check)
// (C) Removes identifying information like names and email addresses
// (D) Saves a DTA to be recoded and appended with the mass public survey

/*

/////////////////////////////////////////////////
// PART 1: 
// CLEAN LINK FROM EMAIL ONLY CONTACT
/////////////////////////////////////////////////
set more off
// this code reads in the CSV and then uses the variable labels (second row) to create variable names (first row). The original first row is qualtrics generated variable names that are meaningless.

clear
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data"

local csvfiles: dir "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data\Email" files "*.csv"
foreach file of local csvfiles {
 preserve
 clear
 insheet using "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data/Email/`file'", names

 
 foreach var of varlist * {
  label variable `var' "`=`var'[1]'"
  replace `var'="" if _n==1
  destring `var', replace
}

 
 save temp, replace
 restore
 append using temp
}

// first row is empty now, so it needs to be dropped
drop if inlist(_n,1) 
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data" 
compress
save ContributorEmail, replace


/////////////////////////////////////////////////
// PART 2:
// CLEAN LINK FROM POSTCARD + EMAIL CONTACT
/////////////////////////////////////////////////

cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data\Postcard"

local csvfiles: dir "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data\Postcard" files "*.csv"
foreach file of local csvfiles {
 preserve
 clear
 insheet using "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data\Postcard/`file'", names
 
 //drop v2096 // empty qualtrics variable (Group 1) that breaks code from type mismatch (it's a blank byte for some reason)
 
 foreach var of varlist * {
  label variable `var' "`=`var'[1]'"
  replace `var'="" if _n==1
  destring `var', replace
}

 
 save temp, replace
 restore
 append using temp
}

// first row is empty now, so it needs to be dropped
drop if inlist(_n,1) 
cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data" 
compress
save ContributorPostcard, replace




/////////////////////////////////////////////////
// PART 3:
// APPEND EMAIL DATASET WITH POSTCARD+ DATASET
/////////////////////////////////////////////////

cd "C:\Users\agooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data" 
use ContributorEmail, clear 
append using ContributorPostcard 
save Contributors_Raw_Survey_Data, replace


////////////////////////////////////////////////////////////////////////////////////////
// PART 4:
// RECODE GROUP ASSIGNMENT, REMOVE INCOMPLETES, NO JAVA SCRIPT, CELL PHONE USERS, ETC
////////////////////////////////////////////////////////////////////////////////////////



// Group is determined by the third issue area
// issues one and two are always aligned
tab thirdposition_d // all possible third positions from those that saw a Dem candidate
tab thirdposition_r // all possible third positions from those that saw a Rep candidate

gen saw_dem = 0 if q32 == 1 // Rep vignette intro page
replace saw_dem = 1 if q51 == 1 // Dem vignette intro page
label var saw_dem " "
label define saw_dem 0 "Republican Candidate" 1 "Democratic Candidate"
label values saw_dem saw_dem 


//DEM CANDIDATE
gen group = ""
replace group = "Aligned" if thirdposition_d =="To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes."
replace group = "Aligned" if thirdposition_d =="To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $175,000 so that more money is raised in taxes"
replace group = "Aligned" if thirdposition_d =="I support may-issue concealed carry gun laws. These laws require approval by local authorities, like the police department, to carry a concealed handgun."  
replace group = "Aligned" if thirdposition_d =="I support no-issue concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun."
replace group = "Aligned" if thirdposition_d =="I support raising the top marginal tax rate to 60% for those making more than $1,000,000."
replace group = "Aligned" if thirdposition_d =="I support raising the top marginal tax rate to 43% for those making more than $1,000,000."
replace group = "Aligned" if thirdposition_d =="I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent."
replace group = "Aligned" if thirdposition_d =="I support making abortion legal during the first trimester of pregnancy for individuals ages 18 years or older without parental consent."
replace group = "Aligned" if thirdposition_d =="I support raising the lifetime cap from 5 years to 9 years."
replace group = "Aligned" if thirdposition_d =="I support raising the lifetime from 5 years to 7 years."
replace group = "Aligned" if thirdposition_d =="I do not support sending additional air power or any ground troops to Syria and Iraq"
replace group = "Aligned" if thirdposition_d =="I support sending additional air power, but not ground troops, to Syria and Iraq. "

replace group = "Extreme" if thirdposition_d =="I support amending the U.S. Constitution to allow confiscating privately owned handguns and to prevent any state from permitting people to carry a concealed handgun." 
replace group = "Extreme" if thirdposition_d =="To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to unlimited (all income is taxed) so that more money is raised in taxes." 
replace group = "Extreme" if thirdposition_d =="I support raising the top marginal tax rate to 90% for those making more than $1,000,000."
replace group = "Extreme" if thirdposition_d =="I support eliminating job search requirements and raising the lifetime cap from 5 years to an unlimited length of time."
replace group = "Extreme" if thirdposition_d =="I support making abortion legal at any time during pregnancy."
replace group = "Extreme" if thirdposition_d =="I support withdrawing all U.S. troops and military resources from Syria and Iraq."

replace group = "Bipartisan" if thirdposition_d =="To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 5%."
replace group = "Bipartisan" if thirdposition_d =="To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%."
replace group = "Bipartisan" if thirdposition_d =="I support shall-issue concealed carry gun laws. These laws require minimal criteria, like residency and age verification, to carry a concealed handgun."
replace group = "Bipartisan" if thirdposition_d =="I support unrestricted concealed carry gun laws. These laws do not require a permit to carry a concealed handgun."
replace group = "Bipartisan" if thirdposition_d =="I support shall-issueconcealed carry gun laws. These laws require minimal criteria, like residency and age verification, to carry a concealed handgun."
replace group = "Bipartisan" if thirdposition_d =="I support reducing the top marginal tax rate to 37%."
replace group = "Bipartisan" if thirdposition_d =="I support reducing the top marginal tax rate to 20%."
replace group = "Bipartisan" if thirdposition_d =="I support making abortion legal only in cases of incest, rape, if the mothers life is endangered, or if the child is expected to have severe deformities."
replace group = "Bipartisan" if thirdposition_d =="I support making abortion legal only in cases where the mothers life is in danger."
replace group = "Bipartisan" if thirdposition_d =="I support reducing the lifetime cap from 5 years to 3 years."
replace group = "Bipartisan" if thirdposition_d =="I support reducing the lifetime cap from 5 years to 1 year."
replace group = "Bipartisan" if thirdposition_d =="I support sending additional air power and 10,000 U.S. ground troops to Syria and Iraq."
replace group = "Bipartisan" if thirdposition_d =="I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq."

replace group = "Unusual" if thirdposition_d=="I support mandatory birth control for all unmarried woman so that abortion is no longer necessary."
replace group = "Unusual" if thirdposition_d=="I support banning concealed handguns. Instead I support setting up concealed handgun stations in public building and private businesses, much like fire extinguishers, so that ordinary citizens can use a handgun in cases of an emergency."
replace group = "Unusual" if thirdposition_d=="I support marginal tax rates that are indexed by age such that at age 18 you start by paying 15%, and it gradually increases to 40% by age 40, and drops to 20% for those aged 65 and older."
replace group = "Unusual" if thirdposition_d=="To keep Social Security solvent, I support eliminating the United States Postal Service and NASA, and instead directing that money to Social Security."
replace group = "Unusual" if thirdposition_d=="I support placing Welfare recipients in work camps, where they will receive free room and board, until they find a job and no longer need assistance."
replace group = "Unusual" if thirdposition_d=="I support occupying the country of Kuwait, which borders Iraq, as a temporary United States territory so that the U.S. military has easy access to ISIS."
replace group = "Unusual" if thirdposition_d=="I support occupying the country of Kuwait, which boarders Iraq, as a temporary United States territory so that the U.S. military has easy access to ISIS."

//REP CANDIDATE
replace group = "Aligned" if thirdposition_r =="To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 5%."
replace group = "Aligned" if thirdposition_r =="To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%."
replace group = "Aligned" if thirdposition_r =="I support shall-issue concealed carry gun laws. These laws require minimal criteria, like residency and age verification, to carry a concealed handgun."
replace group = "Aligned" if thirdposition_r =="I support unrestricted concealed carry gun laws. These laws do not require a permit to carry a concealed handgun."
replace group = "Aligned" if thirdposition_r =="I support reducing the top marginal tax rate to 37%."
replace group = "Aligned" if thirdposition_r =="I support reducing the top marginal tax rate to 20%."
replace group = "Aligned" if thirdposition_r =="I support making abortion legal only in cases of incest, rape, if the mothers life is endangered, or if the child is expected to have severe deformities."
replace group = "Aligned" if thirdposition_r =="I support making abortion legal only in cases where the mothers life is in danger."
replace group = "Aligned" if thirdposition_r =="I support reducing the lifetime cap from 5 years to 3 years."
replace group = "Aligned" if thirdposition_r =="I support reducing the lifetime cap from 5 years to 1 year."
replace group = "Aligned" if thirdposition_r =="I support sending additional air power and 10,000 U.S. ground troops to Syria and Iraq."
replace group = "Aligned" if thirdposition_r =="I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq."

replace group = "Extreme" if thirdposition_r =="I support a law that requires all teachers and university professors to carry concealed handguns for public safety." 
replace group = "Extreme" if thirdposition_r =="I support reducing the top marginal tax rate to 10%." 
replace group = "Extreme" if thirdposition_r =="To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 25% and then freezing benefits for future years."
replace group = "Extreme" if thirdposition_r =="I support outlawing abortion for any circumstance, even to save a mothers life."
replace group = "Extreme" if thirdposition_r =="I support completely eliminating Welfare benefits."
replace group = "Extreme" if thirdposition_r =="I support sending additional air power and 500,000 U.S. ground troops to Syria and Iraq."

replace group = "Bipartisan" if thirdposition_r =="To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes."
replace group = "Bipartisan" if thirdposition_r =="To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $175,000 so that more money is raised in taxes"
replace group = "Bipartisan" if thirdposition_r =="I support may-issue concealed carry gun laws. These laws require approval by local authorities, like the police department, to carry a concealed handgun." 
replace group = "Bipartisan" if thirdposition_r =="I support no-issue concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun."
replace group = "Bipartisan" if thirdposition_r =="I support raising the top marginal tax rate to 60% for those making more than $1,000,000."
replace group = "Bipartisan" if thirdposition_r =="I support raising the top marginal tax rate to 43% for those making more than $1,000,000."
replace group = "Bipartisan" if thirdposition_r =="I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent."
replace group = "Bipartisan" if thirdposition_r =="I support making abortion legal during the first trimester of pregnancy for individuals ages 18 years or older without parental consent."
replace group = "Bipartisan" if thirdposition_r =="I support raising the lifetime cap from 5 years to 9 years."
replace group = "Bipartisan" if thirdposition_r =="I support raising the lifetime from 5 years to 7 years."
replace group = "Bipartisan" if thirdposition_r =="I do not support sending additional air power or any ground troops to Syria and Iraq"
replace group = "Bipartisan" if thirdposition_r =="I support sending additional air power, but not ground troops, to Syria and Iraq. "

replace group = "Unusual" if thirdposition_r=="I support mandatory birth control for all unmarried woman so that abortion is no longer necessary."
replace group = "Unusual" if thirdposition_r=="I support banning concealed handguns. Instead I support setting up concealed handgun stations in public building and private businesses, much like fire extinguishers, so that ordinary citizens can use a handgun in cases of an emergency."
replace group = "Unusual" if thirdposition_r=="I support marginal tax rates that are indexed by age such that at age 18 you start by paying 15%, and it gradually increases to 40% by age 40, and drops to 20% for those aged 65 and older."
replace group = "Unusual" if thirdposition_r=="To keep Social Security solvent, I support eliminating the United States Postal Service and NASA, and instead directing that money to Social Security."
replace group = "Unusual" if thirdposition_r=="I support placing Welfare recipients in work camps, where they will receive free room and board, until they find a job and no longer need assistance. " // note the extra space @ end
replace group = "Unusual" if thirdposition_r=="I support occupying the country of Kuwait, which borders Iraq, as a temporary United States territory so that the U.S. military has easy access to ISIS."
replace group = "Unusual" if thirdposition_r=="I support occupying the country of Kuwait, which boarders Iraq, as a temporary United States territory so that the U.S. military has easy access to ISIS."
label var group "Treatment Group Assignment"

tab election1
gen election = ""
replace election = "lose" if election1== "likely to lose in the general election."
replace election = "win" if election1== "likely to win in the general election."
replace election = "toss up" if election1== "about equally likely to win or lose in the general election."
label var election "Randomized Electoral Competitiveness"

// find the incompletes, cell phone completes, and break offs -> those without a group assignement broke off before the vignette

tab qcell2 v10
tab v10
drop if v10 == 0 // drop incompletes, finished survey ==1, break off ==0 (10.6%)
tab qcell2 
list group if qcell2 == 2 // those on cell phone who lied -> v10==1 ("finished" survey) via bounced from the JavaScript cycle asking to turn on JS -> proof of not taking survey by showing no group assignment
drop if qcell2 == 2 

// rabbit hole looking into those that broke off
sort group
list thirdposition_d if group=="" // there should be none left -> "" means they did not reach the JS page to get a treatment assignment
tab qcell2 if group =="" // 24 non-cell phone respondents broke off before treatment assignment
count if group == ""
tab nojavascript if group =="" // same 24 non-cell phone people above + 88 bounced for no JS
tab nojavascript israndomized // same 24; if noJS == 1 and isRandomized == 0 -> did not get randomized vignette becuase of no JavaScript
list group saw_dem q79 if nojavascript == 1 & israndomized == 1 // keep 4 that mysteriously got through without JS
sort israndomized
drop if israndomized ==0 // No randomization means they did not see vignette. Some did not consent, others broke off and quit
drop if group == "" // 7 non-cell respondents went in the JS enabling loop 4 times then were sent to "finished survey" after the fourth try
tab group // 908 completes as of July 17 (n=637 donors without Unusual Treatment and Independents)


// save a version that removes incompletes but still has identifying data to match with contribution records for Table 1
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data"
save Contributors_SurveyData_Processed_With_Indentifying_Info, replace
 

//drop identifying data (name, address, email)
drop v1 v2 v3 v4 v5 v6 v7 v8 v9 v10
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Data for Analysis"
save Contributors_SurveyData_Processed_DeIndentified, replace


